@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2002 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -14,6 +14,7 @@
 
 #include "cache.h"
 #include "ui_fileops.h"
+#include "ui_spinner.h"
 #include "ui_utildlg.h"
 
 
@@ -74,8 +75,12 @@ static gint isempty(const gchar *path)
 {
 	DIR *dp;
 	struct dirent *dir;
+	gchar *pathl;
 
-	if((dp = opendir(path)) == NULL) return FALSE;
+	pathl = path_from_utf8(path);
+	dp = opendir(pathl);
+	g_free(pathl);
+	if (!dp) return FALSE;
 
 	while ((dir = readdir(dp)) != NULL)
 		{
@@ -150,7 +155,7 @@ static gint cache_maintain_home_cb(gpointer data)
 				    (strlen(path_buf) > base_length && !isfile(path_buf + base_length)) )
 					{
 					if (dot) *dot = '.';
-					if (unlink(path_buf) < 0) printf("failed to delete:%s\n", path_buf);
+					if (!unlink_file(path_buf)) printf("failed to delete:%s\n", path_buf);
 					}
 				else
 					{
@@ -170,7 +175,7 @@ static gint cache_maintain_home_cb(gpointer data)
 		
 		if (cm->list->data == path && just_done)
 			{
-			if (!still_have_a_file && !dlist && cm->list->next && rmdir(path) < 0)
+			if (!still_have_a_file && !dlist && cm->list->next && !rmdir_utf8(path))
 				{
 				printf("Unable to delete dir: %s\n", path);
 				}
@@ -178,8 +183,7 @@ static gint cache_maintain_home_cb(gpointer data)
 		else
 			{
 			/* must re-check for an empty dir */
-			path = cm->list->data;
-			if (isempty(path) && cm->list->next && rmdir(path) < 0)
+			if (isempty(path) && cm->list->next && !rmdir_utf8(path))
 				{
 				printf("Unable to delete dir: %s\n", path);
 				}
@@ -224,6 +228,8 @@ void cache_maintain_home(gint clear)
 	GList *dlist = NULL;
 	gchar *base;
 	const gchar *msg;
+	GtkWidget *hbox;
+	GtkWidget *spinner;
 
 	base = g_strconcat(homedir(), "/", GQVIEW_RC_DIR_THUMBS, NULL);
 
@@ -252,11 +258,20 @@ void cache_maintain_home(gint clear)
 	cm->gd = generic_dialog_new(_("Purge thumbnails"), msg,
 				    "GQview", "purge_thumbnails", TRUE,
 				    cache_maintain_home_cancel_cb, cm);
-	gtk_widget_set_usize(cm->gd->dialog, PURGE_DIALOG_WIDTH, -1);
+	gtk_window_set_default_size(GTK_WINDOW(cm->gd->dialog), PURGE_DIALOG_WIDTH, -1);
+
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(cm->gd->vbox), hbox, FALSE, FALSE, 5);
+	gtk_widget_show(hbox);
+
 	cm->entry = gtk_entry_new();
-	gtk_widget_set_sensitive(cm->entry, FALSE);
-	gtk_box_pack_start(GTK_BOX(cm->gd->vbox), cm->entry, FALSE, FALSE, 5);
+	gtk_editable_set_editable(GTK_EDITABLE(cm->entry), FALSE);
+	gtk_box_pack_start(GTK_BOX(hbox), cm->entry, TRUE, TRUE, 0);
 	gtk_widget_show(cm->entry);
+
+	spinner = spinner_new(NULL, SPINNER_SPEED);
+	gtk_box_pack_start(GTK_BOX(hbox), spinner, FALSE, FALSE, 0);
+	gtk_widget_show(spinner);
 	
 	gtk_widget_show(cm->gd->dialog);
 
@@ -292,7 +307,7 @@ gint cache_maintain_home_dir(const gchar *dir, gint recursive, gint clear)
 			    !cache_maintain_home_dir(path + base_length, recursive, clear))
 				{
 				if (debug) printf("Deleting thumb dir: %s\n", path);
-				if (rmdir(path) < 0)
+				if (!rmdir_utf8(path))
 					{
 					printf("Unable to delete dir: %s\n", path);
 					}
@@ -317,7 +332,7 @@ gint cache_maintain_home_dir(const gchar *dir, gint recursive, gint clear)
 			    (strlen(path) > base_length && !isfile(path + base_length)) )
 				{
 				if (dot) *dot = '.';
-				if (unlink(path) < 0) printf("failed to delete:%s\n", path);
+				if (!unlink_file(path)) printf("failed to delete:%s\n", path);
 				}
 			else
 				{
@@ -370,7 +385,7 @@ gint cache_maintain_dir(const gchar *dir, gint recursive, gint clear)
 				}
 			else
 				{
-				if (unlink(path) < 0)
+				if (!unlink_file(path))
 					{
 					if (debug) printf("Failed to remove cache file %s\n", path);
 					still_have_a_file = TRUE;
@@ -415,7 +430,7 @@ static void cache_file_move(const gchar *src, const gchar *dest)
 		{
 		if (debug) printf("Failed to move cache file %s\nto %s\n", src, dest);
 		/* we remove it anyway - it's stale */
-		unlink(src);
+		unlink_file(src);
 		}
 }
 
@@ -453,7 +468,7 @@ void cache_maint_moved(const gchar *src, const gchar *dest)
 
 static void cache_file_remove(const gchar *path)
 {
-	if (path && isfile(path) && unlink(path) < 0)
+	if (path && isfile(path) && !unlink_file(path))
 		{
 		if (debug) printf("Failed to remove cache file %s\n", path);
 		}
