@@ -832,7 +832,13 @@ static void collection_table_set_focus(CollectTable *ct, CollectInfo *info)
 
 	if (g_list_find(ct->cd->list, ct->focus_info))
 		{
-		if (info == ct->focus_info) return;
+		if (info == ct->focus_info)
+			{
+			/* ensure focus row col are correct */
+			collection_table_find_position(ct, ct->focus_info,
+						       &ct->focus_row, &ct->focus_column);
+			return;
+			}
 		collection_table_selection_remove(ct, ct->focus_info, SELECTION_FOCUS, NULL);
 		}
 
