@@ -908,7 +908,7 @@ static void collection_window_get_geometry(CollectWindow *cw)
 
 	cd = cw->cd;
 	gdk_window_get_position (cw->window->window, &cd->window_x, &cd->window_y);
-	gdk_window_get_size(cw->window->window, &cd->window_w, &cd->window_h);
+	gdk_drawable_get_size(cw->window->window, &cd->window_w, &cd->window_h);
 	cd->window_read = TRUE;
 }
 
