@@ -382,18 +382,7 @@ static void dupe_item_write_cache(DupeItem *di)
 
 		if (cache_sim_data_save(cd))
 			{
-			struct utimbuf ut;
-			/* set time to that of source file */
-
-			ut.actime = ut.modtime = filetime(di->path);
- 			if (ut.modtime > 0)
- 				{
-				gchar *pathl;
-
-				pathl = path_from_utf8(cd->path);
- 				utime(pathl, &ut);
-				g_free(pathl);
- 				}
+			filetime_set(cd->path, filetime(di->path));
 			}
 		cache_sim_data_free(cd);
 		}
