@@ -18,14 +18,19 @@
 #include "ui_spinner.h"
 #include "ui_utildlg.h"
 
+#include <errno.h>
+
 
 #define EDITOR_WINDOW_WIDTH 500
 #define EDITOR_WINDOW_HEIGHT 300
 
+#define COMMAND_SHELL "sh"
+#define COMMAND_OPT  "-c"
+
 
 typedef struct _EditorVerboseData EditorVerboseData;
 struct _EditorVerboseData {
-	FILE *fp;
+	int fd;
 
 	GenericDialog *gd;
 	GtkWidget *button_close;
@@ -121,6 +126,7 @@ static EditorVerboseData *editor_verbose_window(const gchar *template, const gch
 	vd->command_template = g_strdup(template);
 	vd->total = 0;
 	vd->count = 0;
+	vd->fd = -1;
 
 	buf = g_strdup_printf(_("Output of %s"), text);
 	vd->gd = file_util_gen_dlg(_("Edit command results"), buf, "GQview", "editor_results", FALSE,
@@ -221,8 +227,8 @@ static gboolean editor_verbose_io_cb(GIOChannel *source, GIOCondition condition,
 			if (debug) printf("Editor command HUP\n");
 		default:
 			while (g_source_remove_by_user_data(vd));
-			pclose(vd->fp);
-			vd->fp = NULL;
+			close(vd->fd);
+			vd->fd = -1;
 			editor_command_next(vd);
 			return FALSE;
 			break;
@@ -231,15 +237,64 @@ static gboolean editor_verbose_io_cb(GIOChannel *source, GIOCondition condition,
 	return TRUE;
 }
 
-static gint editor_verbose_start(EditorVerboseData *vd, const gchar *command)
+static int command_pipe(char *command)
+{
+	char *args[4];
+	int fpipe[2];
+	pid_t fpid;
+
+	args[0] = COMMAND_SHELL;
+	args[1] = COMMAND_OPT;
+	args[2] = command;
+	args[3] = NULL;
+
+	if (pipe(fpipe) < 0)
+		{
+		printf("pipe setup failed: %s\n", strerror(errno));
+		return -1;
+		}
+
+	fpid = fork();
+	if (fpid < 0)
+		{
+		/* fork failed */
+		printf("fork failed: %s\n", strerror(errno));
+		}
+	else if (fpid == 0)
+		{
+		/* child */
+		gchar *msg;
+
+		dup2(fpipe[1], 1);
+		dup2(fpipe[1], 2);
+		close(fpipe[0]);
+
+		execvp(args[0], args);
+
+		msg = g_strdup_printf("Unable to exec command:\n%s\n\n%s\n", command, strerror(errno));
+		write(1, msg, strlen(msg));
+
+		_exit(1);
+		}
+	else
+		{
+		/* parent */
+		fcntl(fpipe[0], F_SETFL, O_NONBLOCK);
+		close(fpipe[1]);
+
+		return fpipe[0];
+		}
+
+	return -1;
+}
+
+static gint editor_verbose_start(EditorVerboseData *vd, gchar *command)
 	{
-	FILE *f;
 	GIOChannel *channel;
 	int fd;
-	int flags;
 
-	f = popen(command, "r");
-	if (!f)
+	fd = command_pipe(command);
+	if (fd < 0)
 		{
 		gchar *buf;
 
@@ -250,19 +305,9 @@ static gint editor_verbose_start(EditorVerboseData *vd, const gchar *command)
 		return FALSE;
 		}
 
-	/* set our end of pipe non blocking */
-	fd = fileno(f);
-	if ((flags = fcntl(fd, F_GETFL)) >= 0)
-		{
-		flags |= O_NONBLOCK;
-		if (fcntl(fd, F_SETFL, &flags) < 0)
-			{
-			printf("Unable to set non blocking mode for editor pipe\n");
-			}
-		}
+	vd->fd = fd;
+	channel = g_io_channel_unix_new(fd);
 
-	vd->fp = f;
-	channel = g_io_channel_unix_new(fileno(vd->fp));
 	g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, G_IO_IN,
 			    editor_verbose_io_cb, vd, NULL);
 	g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, G_IO_ERR,
