@@ -524,15 +524,29 @@ gchar *text_from_size_abrev(gint64 size)
 	return g_strdup_printf(_("%.1f GB"), (gfloat)size / 1024.0);
 }
 
+/* note: returned string is valid until next call to text_from_time() */
 const gchar *text_from_time(time_t t)
 {
-	static gchar ret[64];
+	static gchar *ret = NULL;
+	gchar buf[128];
+	gint buflen;
 	struct tm *btime;
+	GError *error = NULL;
 
 	btime = localtime(&t);
 
 	/* the %x warning about 2 digit years is not an error */
-	if (strftime(ret, sizeof(ret), "%x %H:%M", btime) < 1) return "";
+	buflen = strftime(buf, sizeof(buf), "%x %H:%M", btime);
+	if (buflen < 1) return "";
+
+	g_free(ret);
+	ret = g_locale_to_utf8(buf, buflen, NULL, NULL, &error);
+	if (error)
+		{
+		printf("Error converting locale strftime to UTF-8: %s\n", error->message);
+		g_error_free(error);
+		return "";
+		}
 
 	return ret;
 }
