@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2002 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -16,6 +16,7 @@
 
 typedef struct _FilterEntry FilterEntry;
 struct _FilterEntry {
+	gchar *key;
 	gchar *description;
 	gchar *extensions;
 	gint enabled;
@@ -25,7 +26,8 @@ struct _FilterEntry {
 GList *filter_get_list(void);
 void filter_remove_entry(FilterEntry *fe);
 
-void filter_add(const gchar *description, const gchar *extensions, gint enabled);
+void filter_add(const gchar *key, const gchar *description, const gchar *extensions, gint enabled);
+void filter_add_unique(const gchar *description, const gchar *extensions, gint enabled);
 void filter_add_defaults(void);
 void filter_reset(void);
 void filter_rebuild(void);
@@ -43,14 +45,14 @@ GList *path_list_filter(GList *list, gint is_dir_list);
 GList *path_list_sort(GList *list);
 GList *path_list_recursive(const gchar *path);
 
-gchar *text_from_size(gint size);
-gchar *text_from_size_abrev(gint size);
+gchar *text_from_size(gint64 size);
+gchar *text_from_size_abrev(gint64 size);
 const gchar *text_from_time(time_t t);
 
 /* path is not const here, the allocated is text
  * is used, not copied - for speed
  */
-FileData *file_data_new(gchar *path, struct stat *st);
+FileData *file_data_new(const gchar *path, struct stat *st);
 void file_data_free(FileData *fd);
 
 GList *filelist_sort(GList *list, SortType method, gint ascend);
