@@ -70,7 +70,7 @@ gint slideshow_delay = 15;
 gint slideshow_random = FALSE;
 gint slideshow_repeat = FALSE;
 
-gint mousewheel_scrolls = TRUE;
+gint mousewheel_scrolls = FALSE;
 gint enable_in_place_rename = TRUE;
 
 gint recent_list_max = 10;
@@ -78,8 +78,8 @@ gint recent_list_max = 10;
 gint collection_rectangular_selection = FALSE;
 
 gint tile_cache_max = 10;
-gint thumbnail_quality = (gint)GDK_INTERP_NEAREST;
-gint zoom_quality = (gint)GDK_INTERP_NEAREST;
+gint thumbnail_quality = (gint)GDK_INTERP_TILES;
+gint zoom_quality = (gint)GDK_INTERP_BILINEAR;
 gint dither_quality = (gint)GDK_RGB_DITHER_NORMAL;
 
 gint zoom_increment = 5;
