@@ -712,12 +712,12 @@ static void image_queue(ImageWindow *imd, gint x, gint y, gint w, gint h,
 	nx = CLAMP(x, 0, imd->width - 1);
 	ny = CLAMP(y, 0, imd->height - 1);
 	w -= (nx - x);
-	h -= (nx - x);
-	w = CLAMP(w, 0, imd->width - x);
-	h = CLAMP(h, 0, imd->height - y);
+	h -= (ny - y);
+	w = CLAMP(w, 0, imd->width - nx);
+	h = CLAMP(h, 0, imd->height - ny);
 	if (w < 1 || h < 1) return;
 
-	if (image_queue_to_tiles(imd, x, y, w, h, clamp, render, new_data) &&
+	if (image_queue_to_tiles(imd, nx, ny, w, h, clamp, render, new_data) &&
 	    ((!imd->draw_queue && !imd->draw_queue_2pass) || imd->draw_idle_id == -1 || !imd->draw_idle_high))
 		{
 		if (imd->draw_idle_id != -1) gtk_idle_remove(imd->draw_idle_id);
@@ -1142,15 +1142,6 @@ static void image_scroll_real(ImageWindow *imd, gint x, gint y)
 				  x1 + imd->x_offset, y1 + imd->y_offset, w, h);
 		g_object_unref(gc);
 
-		/*
-		 * RACE CONDITION avoidance for expose_event and scrolling (hack):
-		 * [borrowed from eog - Eye of Gnome]
-		 * this is really terrible to do, but the expose_events must be done right now,
-		 * otherwise the signal may not be sent until after another scroll and that would
-		 * cause portions of the image to never be redrawn (the part needing update now would
-		 * then be in a different screen location).
-		 */
-
 		w = imd->vis_width - w;
 		h = imd->vis_height - h;
 
@@ -1168,8 +1159,6 @@ static void image_scroll_real(ImageWindow *imd, gint x, gint y)
 				    imd->vis_width, h, TRUE, TILE_RENDER_ALL, FALSE);
 			}
 		}
-
-	
 }
 
 static void widget_set_cursor(GtkWidget *widget, gint icon)
@@ -1888,13 +1877,11 @@ static gint image_expose_cb(GtkWidget *widget, GdkEventExpose *event, gpointer d
 	return TRUE;
 }
 
-static gint image_size_cb(GtkWidget *widget, GtkAllocation *allocation, gpointer data)
+static void image_size_cb(GtkWidget *widget, GtkAllocation *allocation, gpointer data)
 {
 	ImageWindow *imd = data;
 
 	image_size_sync(imd, allocation->width, allocation->height);
-
-	return FALSE;
 }
 
 /*
