@@ -22,9 +22,12 @@ void image_attach_window(ImageWindow *imd, GtkWidget *window,
 void image_set_update_func(ImageWindow *imd,
 			   void (*func)(ImageWindow *imd, gpointer data),
 			   gpointer data);
-void image_set_button_func(ImageWindow *imd, gint button,
-			   void (*func)(ImageWindow *, guint32 time, gdouble x, gdouble y, guint state, gpointer),
-			   gpointer data);
+void image_set_button_func(ImageWindow *imd,
+	void (*func)(ImageWindow *, gint button, guint32 time, gdouble x, gdouble y, guint state, gpointer),
+	gpointer data);
+void image_set_scroll_func(ImageWindow *imd,
+	void (*func)(ImageWindow *, GdkScrollDirection direction, guint32 time, gdouble x, gdouble y, guint state, gpointer),
+        gpointer data);
 void image_set_complete_func(ImageWindow *imd,
 			     void (*func)(ImageWindow *, gint preload, gpointer),
 			     gpointer data);
