@@ -396,6 +396,9 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 		case '9':
 			image_zoom_set(imd, -2.0);
 			break;
+		case 'R': case 'r':
+			image_reload(imd);
+			break;
 		case 'S': case 's':
 			if (vw->ss)
 				view_slideshow_stop(vw);
@@ -422,8 +425,7 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 		case GDK_Delete: case GDK_KP_Delete:
 			if (enable_delete_key)
 				{
-				view_fullscreen_toggle(vw, TRUE);
-				file_util_delete(image_get_path(vw->imd), NULL);
+				file_util_delete(image_get_path(imd), NULL);
 				stop_signal = TRUE;
 				}
 			break;
@@ -482,28 +484,23 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 				n = 9;
 				break;
 			case 'C': case 'c':
-				view_fullscreen_toggle(vw, TRUE);
-				file_util_copy(image_get_path(vw->imd), NULL, NULL);
+				file_util_copy(image_get_path(imd), NULL, NULL);
 				stop_signal = TRUE;
 				break;
 			case 'M': case 'm':
-				view_fullscreen_toggle(vw, TRUE);
-				file_util_move(image_get_path(vw->imd), NULL, NULL);
+				file_util_move(image_get_path(imd), NULL, NULL);
 				stop_signal = TRUE;
 				break;
 			case 'R': case 'r':
-				view_fullscreen_toggle(vw, TRUE);
-				file_util_rename(image_get_path(vw->imd), NULL);
+				file_util_rename(image_get_path(imd), NULL);
 				stop_signal = TRUE;
 				break;
 			case 'D': case 'd':
-				view_fullscreen_toggle(vw, TRUE);
-				file_util_delete(image_get_path(vw->imd), NULL);
+				file_util_delete(image_get_path(imd), NULL);
 				stop_signal = TRUE;
 				break;
 			case 'P': case 'p':
-				view_fullscreen_toggle(vw, TRUE);
-				info_window_new(image_get_path(vw->imd), NULL);
+				info_window_new(image_get_path(imd), NULL);
 				stop_signal = TRUE;
 				break;
 			case 'W': case 'w':
@@ -927,9 +924,10 @@ static void view_alter_cb(GtkWidget *widget, gpointer data)
 static void view_info_cb(GtkWidget *widget, gpointer data)
 {
 	ViewWindow *vw = data;
+	ImageWindow *imd;
 
-	view_fullscreen_toggle(vw, TRUE);
-	info_window_new(image_get_path(vw->imd), NULL);
+	imd = view_window_active_image(vw);
+	info_window_new(image_get_path(imd), NULL);
 }
 
 static void view_wallpaper_cb(GtkWidget *widget, gpointer data)
@@ -938,7 +936,6 @@ static void view_wallpaper_cb(GtkWidget *widget, gpointer data)
 	ImageWindow *imd;
 
 	imd = view_window_active_image(vw);
-
 	image_to_root_window(imd, (image_zoom_get(imd) == 0.0));
 }
 
@@ -973,33 +970,37 @@ static void view_zoom_fit_cb(GtkWidget *widget, gpointer data)
 static void view_copy_cb(GtkWidget *widget, gpointer data)
 {
 	ViewWindow *vw = data;
+	ImageWindow *imd;
 
-	view_fullscreen_toggle(vw, TRUE);
-	file_util_copy(image_get_path(vw->imd), NULL, NULL);
+	imd = view_window_active_image(vw);
+	file_util_copy(image_get_path(imd), NULL, NULL);
 }
 
 static void view_move_cb(GtkWidget *widget, gpointer data)
 {
 	ViewWindow *vw = data;
+	ImageWindow *imd;
 
-	view_fullscreen_toggle(vw, TRUE);
-	file_util_move(image_get_path(vw->imd), NULL, NULL);
+	imd = view_window_active_image(vw);
+	file_util_move(image_get_path(imd), NULL, NULL);
 }
 
 static void view_rename_cb(GtkWidget *widget, gpointer data)
 {
 	ViewWindow *vw = data;
+	ImageWindow *imd;
 
-	view_fullscreen_toggle(vw, TRUE);
-	file_util_rename(image_get_path(vw->imd), NULL);
+	imd = view_window_active_image(vw);
+	file_util_rename(image_get_path(imd), NULL);
 }
 
 static void view_delete_cb(GtkWidget *widget, gpointer data)
 {
 	ViewWindow *vw = data;
+	ImageWindow *imd;
 
-	view_fullscreen_toggle(vw, TRUE);
-	file_util_delete(image_get_path(vw->imd), NULL);
+	imd = view_window_active_image(vw);
+	file_util_delete(image_get_path(imd), NULL);
 }
 
 static void view_fullscreen_cb(GtkWidget *widget, gpointer data)
