@@ -62,9 +62,7 @@ gint layout_valid(LayoutWindow **lw)
 		return (*lw != NULL);
 		}
 
-	/* eventualy we will check layout_list that lw exists,
-	   for now only 1 layout window is allowed */
-	return TRUE;
+	return (g_list_find(layout_window_list, *lw) != NULL);
 }
 
 /*
@@ -80,7 +78,7 @@ static void layout_path_entry_changed_cb(GtkWidget *widget, gpointer data)
 	gchar *buf;
 
 	buf = g_strdup(gtk_entry_get_text(GTK_ENTRY(lw->path_entry)));
-	if (!buf || strcmp(buf, lw->path) == 0)
+	if (!buf || (lw->path && strcmp(buf, lw->path) == 0))
 		{
 		g_free(buf);
 		return;
@@ -1023,7 +1021,11 @@ static void layout_tools_hide(LayoutWindow *lw, gint hide)
 		}
 	else
 		{
-		if (!GTK_WIDGET_VISIBLE(lw->tools)) gtk_widget_show(lw->tools);
+		if (!GTK_WIDGET_VISIBLE(lw->tools))
+			{
+			gtk_widget_show(lw->tools);
+			if (lw->vfi) vficon_refresh(lw->vfi);
+			}
 		}
 
 	lw->tools_hidden = hide;
@@ -1062,6 +1064,7 @@ static void layout_tools_setup(LayoutWindow *lw, GtkWidget *tools, GtkWidget *fi
 		lw->tools = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 		g_signal_connect(G_OBJECT(lw->tools), "delete_event",
 				 G_CALLBACK(layout_tools_delete_cb), lw);
+		layout_keyboard_init(lw, lw->tools);
 
 		geometry.min_width = 32;
 		geometry.min_height = 32;
@@ -1639,7 +1642,7 @@ LayoutWindow *layout_new(const gchar *path, gint popped, gint hidden)
 	g_signal_connect(G_OBJECT(lw->window), "delete_event",
 			 G_CALLBACK(layout_delete_cb), lw);
 
-	layout_keyboard_init(lw);
+	layout_keyboard_init(lw, lw->window);
 
 #if 0
 	gtk_widget_realize(lw->window);
