@@ -115,9 +115,9 @@ static void layout_config_list_order_set(LayoutConfig *lc, gint src, gint dest)
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
 	while (valid)
 		{
-		if (n == src)
+		if (n == dest)
 			{
-			gtk_list_store_set(store, &iter, COLUMN_TEXT, _(layout_titles[dest]), COLUMN_KEY, dest, -1);
+			gtk_list_store_set(store, &iter, COLUMN_TEXT, _(layout_titles[src]), COLUMN_KEY, src, -1);
 			return;
 			}
 		n++;
