@@ -41,18 +41,6 @@ static void layout_image_set_buttons(LayoutWindow *lw);
  *----------------------------------------------------------------------------
  */
 
-static void layout_image_full_screen_regrab_cb(GtkWidget *widget, gpointer data)
-{
-	LayoutWindow *lw = data;
-
-	/* full screen, re-grab keyboard after popup-menu close */
-	if (lw->full_screen)
-		{
-		gdk_keyboard_grab(lw->full_screen->window->window, TRUE, GDK_CURRENT_TIME);
-		}
-}
-
-
 static void layout_image_fullscreen_menu_pos_cb(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 {
 	LayoutWindow *lw = data;
@@ -69,12 +57,6 @@ static void layout_image_full_screen_menu_popup(LayoutWindow *lw)
 
 	menu = layout_image_pop_menu(lw);
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, layout_image_fullscreen_menu_pos_cb, lw, 0, GDK_CURRENT_TIME);
-	if (lw->full_screen)
-		{ 
-		/* full screen, re-grab keyboard after popup-menu close */
-		g_signal_connect(G_OBJECT(menu), "selection_done",
-				 G_CALLBACK(layout_image_full_screen_regrab_cb), lw);
-		}
 }
 
 static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
@@ -165,7 +147,6 @@ static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey
 		case GDK_Delete: case GDK_KP_Delete:
 			if (enable_delete_key)
 				{
-				if (confirm_delete) layout_image_full_screen_stop(lw);
 				file_util_delete(layout_image_get_path(lw), NULL);
 				stop_signal = TRUE;
 				}
@@ -174,6 +155,9 @@ static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey
 			layout_image_full_screen_stop(lw);
 			stop_signal = TRUE;
 			break;
+		case 'R': case 'r':
+			layout_refresh(lw);
+			break;
 		case 'S': case 's':
 			layout_image_slideshow_toggle(lw);
 			break;
@@ -227,23 +211,18 @@ static gint layout_image_full_screen_key_press_cb(GtkWidget *widget, GdkEventKey
 				n = 9;
 				break;
 			case 'C': case 'c':
-				layout_image_full_screen_stop(lw);
 				file_util_copy(layout_image_get_path(lw), NULL, NULL);
 				break;
 			case 'M': case 'm':
-				layout_image_full_screen_stop(lw);
 				file_util_move(layout_image_get_path(lw), NULL, NULL);
 				break;
 			case 'R': case 'r':
-				layout_image_full_screen_stop(lw);
 				file_util_rename(layout_image_get_path(lw), NULL);
 				break;
 			case 'D': case 'd':
-				if (confirm_delete) layout_image_full_screen_stop(lw);
 				file_util_delete(layout_image_get_path(lw), NULL);
 				break;
 			case 'P': case 'p':
-				layout_image_full_screen_stop(lw);
 				info_window_new(layout_image_get_path(lw), NULL);
 				break;
 			case 'Q': case 'q':
@@ -563,7 +542,6 @@ static void li_pop_menu_info_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_image_full_screen_stop(lw);
 	info_window_new(layout_image_get_path(lw), NULL);
 }
 
@@ -578,7 +556,6 @@ static void li_pop_menu_copy_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_image_full_screen_stop(lw);
 	file_util_copy(layout_image_get_path(lw), NULL, NULL);
 }
 
@@ -586,7 +563,6 @@ static void li_pop_menu_move_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_image_full_screen_stop(lw);
 	file_util_move(layout_image_get_path(lw), NULL, NULL);
 }
 
@@ -594,7 +570,6 @@ static void li_pop_menu_rename_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_image_full_screen_stop(lw);
 	file_util_rename(layout_image_get_path(lw), NULL);
 }
 
@@ -602,7 +577,6 @@ static void li_pop_menu_delete_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
 
-	layout_image_full_screen_stop(lw);
 	file_util_delete(layout_image_get_path(lw), NULL);
 }
 
@@ -1226,12 +1200,6 @@ static void layout_image_button_cb(ImageWindow *imd, gint button, guint32 time,
 		case 3:
 			menu = layout_image_pop_menu(lw);
 			gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, 3, time);
-			if (lw->full_screen)
-				{
-				/* full screen, re-grab keyboard after popup-menu close */
-				g_signal_connect(G_OBJECT(menu), "selection_done",
-						 G_CALLBACK(layout_image_full_screen_regrab_cb), lw);
-				}
 			break;
 		default:
 			break;
@@ -1315,7 +1283,7 @@ GtkWidget *layout_image_new(LayoutWindow *lw, const gchar *path)
 {
 	if (!lw->image) 
 		{
-		lw->image = image_new(TRUE);
+		lw->image = image_new( (!lw->tools_float && !lw->tools_hidden) );
 		if (black_window_background) image_background_set_black(lw->image, TRUE);
 		image_set_update_func(lw->image, layout_image_update_cb, lw);
 		layout_image_set_buttons(lw);
