@@ -96,7 +96,8 @@ static gint layout_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer
 		return TRUE;
 		}
 
-	if (lw->image && GTK_WIDGET_HAS_FOCUS(lw->image->widget))
+	if (lw->image &&
+	    (GTK_WIDGET_HAS_FOCUS(lw->image->widget) || (lw->tools && widget == lw->window)) )
 		{
 		switch (event->keyval)
 			{
@@ -211,7 +212,7 @@ static gint layout_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer
 			layout_image_slideshow_pause_toggle(lw);
 			break;
 		case 'V': case 'v':
-			layout_image_full_screen_toggle(lw);
+			if (!(event->state & GDK_MOD1_MASK)) layout_image_full_screen_toggle(lw);
 			break;
 		}
 
@@ -232,9 +233,9 @@ static gint layout_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer
 	return stop_signal;
 }
 
-void layout_keyboard_init(LayoutWindow *lw)
+void layout_keyboard_init(LayoutWindow *lw, GtkWidget *window)
 {
-	g_signal_connect(G_OBJECT(lw->window), "key_press_event",
+	g_signal_connect(G_OBJECT(window), "key_press_event",
 			 G_CALLBACK(layout_key_press_cb), lw);
 }
 
@@ -459,7 +460,7 @@ static void layout_menu_full_screen_cb(gpointer data, guint action, GtkWidget *w
 {
 	LayoutWindow *lw = data;
 
-	layout_image_full_screen_start(lw);
+	layout_image_full_screen_toggle(lw);
 }
 
 static void layout_menu_refresh_cb(gpointer data, guint action, GtkWidget *widget)
