@@ -33,7 +33,7 @@ GtkWidget *layout_button(GtkWidget *box, gchar **pixmap_data, const gchar *stock
 			 GtkSignalFunc func, gpointer data);
 GtkWidget *layout_button_bar(LayoutWindow *lw);
 
-void layout_keyboard_init(LayoutWindow *lw);
+void layout_keyboard_init(LayoutWindow *lw, GtkWidget *window);
 
 
 PixmapFolders *folder_icons_new(void);
