@@ -95,19 +95,7 @@ gfloat get_zoom_increment(void)
 	return (zoom_increment ? zoom_increment / 10.0 : 1.0);
 }
 
-static gint file_extension_match(const gchar *path, const gchar *ext)
-{
-	gint p;
-	gint e;
 
-	if (!path) return FALSE;
-	if (!ext) return TRUE;
-
-	p = strlen(path);
-	e = strlen(ext);
-
-	return (p > e && strncasecmp(path + p - e, ext, e) == 0);
-}
 /*
  *-----------------------------------------------------------------------------
  * help window
