@@ -445,7 +445,7 @@ static void add_menu_item(GtkWidget *menu, gchar *text, gint *option_c, gint typ
 	gtk_widget_show(item);
 }
 
-static void add_quality_menu(gint option, gint *option_c, gchar *text, GtkWidget *box, gint allow_tiles)
+static void add_quality_menu(gint option, gint *option_c, gchar *text, GtkWidget *box)
 {
 	GtkWidget *hbox;
 	GtkWidget *label;
@@ -466,13 +466,12 @@ static void add_quality_menu(gint option, gint *option_c, gchar *text, GtkWidget
 	menu = gtk_menu_new();
 
 	add_menu_item(menu, _("Nearest (worst, but fastest)"), option_c, (gint)GDK_INTERP_NEAREST);
-	if (allow_tiles) add_menu_item(menu, _("Tiles"), option_c, (gint)GDK_INTERP_TILES);
+	add_menu_item(menu, _("Tiles"), option_c, (gint)GDK_INTERP_TILES);
 	add_menu_item(menu, _("Bilinear"), option_c, (gint)GDK_INTERP_BILINEAR);
 	add_menu_item(menu, _("Hyper (best, but slowest)"), option_c, (gint)GDK_INTERP_HYPER);
 
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(omenu), menu);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(omenu),
-			(!allow_tiles && *option_c > (gint)GDK_INTERP_TILES) ? *option_c - 1 : *option_c);
+	gtk_option_menu_set_history(GTK_OPTION_MENU(omenu), *option_c);
 
 	gtk_box_pack_start(GTK_BOX(hbox), omenu, FALSE, FALSE, 0);
 	gtk_widget_show(omenu);
@@ -915,7 +914,7 @@ static void config_window_create(void)
 
 	add_thumb_size_menu(_("Size:"), vbox1);
 
-	add_quality_menu(thumbnail_quality, &thumbnail_quality_c, _("Quality:"), vbox1, TRUE);
+	add_quality_menu(thumbnail_quality, &thumbnail_quality_c, _("Quality:"), vbox1);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
@@ -978,7 +977,7 @@ static void config_window_create(void)
 	gtk_widget_show(vbox1);
 
 	add_dither_menu(dither_quality, &dither_quality_c, _("Dithering method:"), vbox1);
-	add_quality_menu(zoom_quality, &zoom_quality_c, _("Zoom (scaling):"), vbox1, !(GDK_PIXBUF_TILES_BROKEN));
+	add_quality_menu(zoom_quality, &zoom_quality_c, _("Zoom (scaling):"), vbox1);
 	add_check_button(two_pass_zoom, &two_pass_zoom_c, _("Two pass zooming"), vbox1);
 
 	frame = gtk_frame_new(_("When new image is selected:"));
