@@ -564,22 +564,5 @@ void load_options(void)
 
 	fclose(f);
 	g_free(rc_path);
-
-	if (GDK_PIXBUF_TILES_BROKEN)
-		{
-		printf("Your version of gdk-pixbuf has buggy scaling, TILES zoom quality disabled.");
-		printf(" (upgrade gdk-pixbuf to at least 0.16.0 to fix this.\n");
-		if ((GdkInterpType)zoom_quality == GDK_INTERP_TILES)
-			{
-			/* this is not so bad, the new and old gdk-pixbufs/GQviews are about
-			 * the same speed for these two scale qualities.
-			 * the message does not need translation, it planned for removal, whether
-			 * it will be because of a fixed gdk-pixbuf or simpy dropped, is TBD.
-			 */
-			zoom_quality = (gint)GDK_INTERP_BILINEAR;
-			printf("Important message:\n");
-			printf("Newer gdk-pixbuf has broken tile quality scaling, changing to bilinear.\n");
-			}
-		}
 }
 
