@@ -275,18 +275,14 @@ struct _ImageWindow
 	gpointer data_update;
 	gpointer data_complete;
 
-	/* button functions */
-	void (*func_btn1)(ImageWindow *, guint32 time, gdouble x, gdouble y, guint state, gpointer);
-	void (*func_btn2)(ImageWindow *, guint32 time, gdouble x, gdouble y, guint state, gpointer);
-	void (*func_btn3)(ImageWindow *, guint32 time, gdouble x, gdouble y, guint state, gpointer);
-	void (*func_btn4)(ImageWindow *, guint32 time, gdouble x, gdouble y, guint state, gpointer);
-	void (*func_btn5)(ImageWindow *, guint32 time, gdouble x, gdouble y, guint state, gpointer);
+	/* button, scroll functions */
+	void (*func_button)(ImageWindow *, gint button,
+			    guint32 time, gdouble x, gdouble y, guint state, gpointer);
+	void (*func_scroll)(ImageWindow *, GdkScrollDirection direction,
+			    guint32 time, gdouble x, gdouble y, guint state, gpointer);
 
-	gpointer data_btn1;
-	gpointer data_btn2;
-	gpointer data_btn3;
-	gpointer data_btn4;
-	gpointer data_btn5;
+	gpointer data_button;
+	gpointer data_scroll;
 
 	/* collection info */
 	CollectionData *collection;
