@@ -204,7 +204,10 @@ static void history_list_free(HistoryData *hd)
 static HistoryData *history_list_find_by_key(const gchar* key)
 {
 	GList *work = history_list;
-	while(work)
+
+	if (!key) return NULL;
+
+	while (work)
 		{
 		HistoryData *hd = work->data;
 		if (strcmp(hd->key, key) == 0) return hd;
@@ -1415,7 +1418,7 @@ gchar *uri_text_from_list(GList *list, gint *len, gint plain_text)
 		else
 			{
 			g_string_append(string, name8);
-			if (work->next) g_string_append(string, "\r\n");
+			if (work->next) g_string_append(string, "\n");
 			}
 
 		work = work->next;
