@@ -17,11 +17,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <time.h>
 #include <unistd.h>
 #include <sys/param.h>
-#include <sys/time.h>
-#include <sys/types.h>
 #include <dirent.h>
 #include <utime.h>
 
@@ -51,6 +48,25 @@ void print_term(const gchar *text_utf8)
 	g_free(text_l);
 }
 
+static void encoding_dialog(const gchar *path);
+
+static gint encoding_dialog_idle(gpointer data)
+{
+	gchar *path = data;
+
+	encoding_dialog(path);
+	g_free(path);
+
+	return FALSE;
+}
+
+static gint encoding_dialog_delay(gpointer data)
+{
+	gtk_idle_add(encoding_dialog_idle, data);
+
+	return 0;
+}
+
 static void encoding_dialog(const gchar *path)
 {
 	static gint warned_user = FALSE;
@@ -60,7 +76,12 @@ static void encoding_dialog(const gchar *path)
 	const gchar *bf;
 
 	/* check that gtk is initialized (loop is level > 0) */
-	if (gtk_main_level() == 0) return;
+	if (gtk_main_level() == 0)
+		{
+		/* gtk not initialized */
+		gtk_init_add(encoding_dialog_delay, g_strdup(path));
+		return;
+		}
 
 	if (warned_user) return;
 	warned_user = TRUE;
@@ -209,6 +230,25 @@ time_t filetime(const gchar *s)
 	return st.st_mtime;
 }
 
+gint filetime_set(const gchar *s, time_t tval)
+{
+	gint ret = FALSE;
+
+	if (tval > 0)
+		{
+		struct utimbuf ut;
+		gchar *sl;
+
+		ut.actime = ut.modtime = tval;
+
+		sl = path_from_utf8(s);
+		ret = (utime(sl, &ut) == 0);
+		g_free(sl);
+		}
+
+	return ret;
+}
+
 gint access_file(const gchar *s, int mode)
 {
 	gchar *sl;
@@ -237,6 +277,25 @@ gint unlink_file(const gchar *s)
 	return ret;
 }
 
+gint symlink_utf8(const gchar *source, const gchar *target)
+{
+	gchar *sl;
+	gchar *tl;
+	gint ret;
+
+	if (!source || !target) return FALSE;
+
+	sl = path_from_utf8(source);
+	tl = path_from_utf8(target);
+
+	ret = (symlink(sl, tl) == 0);
+
+	g_free(sl);
+	g_free(tl);
+
+	return ret;
+}
+
 gint mkdir_utf8(const gchar *s, int mode)
 {
 	gchar *sl;
@@ -297,30 +356,52 @@ gint copy_file_attributes(const gchar *s, const gchar *t)
 	return ret;
 }
 
+/* paths are in filesystem encoding */
+static gint hard_linked(const gchar *a, const gchar *b)
+{
+	struct stat sta;
+	struct stat stb;
+
+	if (stat(a, &sta) !=  0 || stat(b, &stb) != 0) return FALSE;
+
+	return (sta.st_dev == stb.st_dev &&
+		sta.st_ino == stb.st_ino);
+}
+
 gint copy_file(const gchar *s, const gchar *t)
 {
-	FILE *fi, *fo;
+	FILE *fi = NULL;
+	FILE *fo = NULL;
 	gchar *sl, *tl;
 	gchar buf[4096];
 	gint b;
 
 	sl = path_from_utf8(s);
-	fi = fopen(sl, "rb");
-	g_free(sl);
-	if (!fi)
+	tl = path_from_utf8(t);
+
+	if (hard_linked(sl, tl))
 		{
-		return FALSE;
+		g_free(sl);
+		g_free(tl);
+		return TRUE;
 		}
 
-	tl = path_from_utf8(t);
-	fo = fopen(tl, "wb");
-	g_free(tl);
-	if (!fo)
+	fi = fopen(sl, "rb");
+	if (fi)
 		{
-		fclose(fi);
-		return FALSE;
+		fo = fopen(tl, "wb");
+		if (!fo)
+			{
+			fclose(fi);
+			fi = NULL;
+			}
 		}
 
+	g_free(sl);
+	g_free(tl);
+
+	if (!fi || !fo) return FALSE;
+
 	while((b = fread(buf, sizeof(char), 4096, fi)) && b != 0)
 		{
 		if (fwrite(buf, sizeof(char), b, fo) != b)
@@ -377,7 +458,7 @@ gint rename_file(const gchar *s, const gchar *t)
 	gint ret;
 
 	if (!s || !t) return FALSE;
-                                                                                                                               
+
 	sl = path_from_utf8(s);
 	tl = path_from_utf8(t);
 	ret = (rename(sl, tl) == 0);
@@ -619,6 +700,20 @@ const gchar *extension_from_path(const gchar *path)
 	return strrchr(path, '.');
 }
 
+gint file_extension_match(const gchar *path, const gchar *ext)
+{
+	gint p;
+	gint e;
+
+	if (!path) return FALSE;
+	if (!ext) return TRUE;
+
+	p = strlen(path);
+	e = strlen(ext);
+
+	return (p > e && strncasecmp(path + p - e, ext, e) == 0);
+}
+
 gchar *remove_extension_from_path(const gchar *path)
 {
 	gchar *new_path;
