@@ -1059,7 +1059,12 @@ static void vficon_set_focus(ViewFileIcon *vfi, FileData *fd)
 
 	if (g_list_find(vfi->list, vfi->focus_fd))
 		{
-		if (fd == vfi->focus_fd) return;
+		if (fd == vfi->focus_fd)
+			{
+			/* ensure focus row col are correct */
+			vficon_find_position(vfi, vfi->focus_fd, &vfi->focus_row, &vfi->focus_column);
+			return;
+			}
 		vficon_selection_remove(vfi, vfi->focus_fd, SELECTION_FOCUS, NULL);
 		}
 
@@ -1796,7 +1801,11 @@ static gint vficon_thumb_next(ViewFileIcon *vfi)
 	GtkTreePath *tpath;
 	FileData *fd = NULL;
 
-	if (!GTK_WIDGET_REALIZED(vfi->listview)) return FALSE;
+	if (!GTK_WIDGET_REALIZED(vfi->listview))
+		{
+		vficon_thumb_status(vfi, 0.0, NULL);
+		return FALSE;
+		}
 
 	if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(vfi->listview), 0, 0, &tpath, NULL, NULL, NULL))
 		{
@@ -2409,6 +2418,8 @@ gint vficon_maint_removed(ViewFileIcon *vfi, const gchar *path, GList *ignore_li
 	FileData *fd;
 	gint row;
 	gint new_row = -1;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
 	row = vficon_index_by_path(vfi, path);
 	if (row < 0) return FALSE;
@@ -2502,6 +2513,17 @@ gint vficon_maint_removed(ViewFileIcon *vfi, const gchar *path, GList *ignore_li
 	if (vfi->prev_selection == fd) vfi->prev_selection = NULL;
 	if (vfi->click_fd == fd) vfi->click_fd = NULL;
 
+	/* remove pointer to this fd from grid */
+	store = gtk_tree_view_get_model(GTK_TREE_VIEW(vfi->listview));
+	if (gtk_tree_model_iter_nth_child(store, &iter, NULL, row / vfi->columns))
+		{
+		GList *list;
+
+		gtk_tree_model_get(store, &iter, FILE_COLUMN_POINTER, &list, -1);
+		list = g_list_find(list, fd);
+		if (list) list->data = NULL;
+		}
+
 	vfi->list = g_list_remove(vfi->list, fd);
 	file_data_free(fd);
 
